@@ -10,6 +10,9 @@ def alpha_geodesic(
     r"""
     $\alpha$-geodesic between two probability distributions
     """
+
+    a += 1e-12
+    b += 1e-12
     if alpha == 1:
         return torch.exp((1 - lmd) * torch.log(a) + lmd * torch.log(b))
     elif alpha >= 1e+9:
@@ -18,4 +21,8 @@ def alpha_geodesic(
         return torch.max(a, b)
     else:
         p = (1 - alpha) / 2
-        return ((1 - lmd) * (a ** p) + lmd * (b ** p)) ** (1/p)
+        a = a ** p
+        b = b ** p
+        g = ((1 - lmd) * a + lmd * b) ** (1/p)
+
+        return g
